==> cdktf-provider-google-2.0.22-sources.jar: com/hashicorp/cdktf/providers/google/BigtableInstanceClusterAutoscalingConfig.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-12T00:46:04.534Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.BigtableInstanceClusterAutoscalingConfig")
@software.amazon.jsii.Jsii.Proxy(BigtableInstanceClusterAutoscalingConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BigtableInstanceClusterAutoscalingConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The target CPU utilization for autoscaling. Value must be between 10 and 80.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#cpu_target BigtableInstance#cpu_target}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getCpuTarget();

    /**
     * The maximum number of nodes for autoscaling.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#max_nodes BigtableInstance#max_nodes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getMaxNodes();

    /**
     * The minimum number of nodes for autoscaling.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#min_nodes BigtableInstance#min_nodes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getMinNodes();

    /**
     * @return a {@link Builder} of {@link BigtableInstanceClusterAutoscalingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BigtableInstanceClusterAutoscalingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BigtableInstanceClusterAutoscalingConfig> {
        java.lang.Number cpuTarget;
        java.lang.Number maxNodes;
        java.lang.Number minNodes;

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getCpuTarget}
         * @param cpuTarget The target CPU utilization for autoscaling. Value must be between 10 and 80. This parameter is required.
         *                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#cpu_target BigtableInstance#cpu_target}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuTarget(java.lang.Number cpuTarget) {
            this.cpuTarget = cpuTarget;
            return this;
        }

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getMaxNodes}
         * @param maxNodes The maximum number of nodes for autoscaling. This parameter is required.
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#max_nodes BigtableInstance#max_nodes}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxNodes(java.lang.Number maxNodes) {
            this.maxNodes = maxNodes;
            return this;
        }

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getMinNodes}
         * @param minNodes The minimum number of nodes for autoscaling. This parameter is required.
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#min_nodes BigtableInstance#min_nodes}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minNodes(java.lang.Number minNodes) {
            this.minNodes = minNodes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BigtableInstanceClusterAutoscalingConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BigtableInstanceClusterAutoscalingConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BigtableInstanceClusterAutoscalingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BigtableInstanceClusterAutoscalingConfig {
        private final java.lang.Number cpuTarget;
        private final java.lang.Number maxNodes;
        private final java.lang.Number minNodes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cpuTarget = software.amazon.jsii.Kernel.get(this, "cpuTarget", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.maxNodes = software.amazon.jsii.Kernel.get(this, "maxNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.minNodes = software.amazon.jsii.Kernel.get(this, "minNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cpuTarget = java.util.Objects.requireNonNull(builder.cpuTarget, "cpuTarget is required");
            this.maxNodes = java.util.Objects.requireNonNull(builder.maxNodes, "maxNodes is required");
            this.minNodes = java.util.Objects.requireNonNull(builder.minNodes, "minNodes is required");
        }

        @Override
        public final java.lang.Number getCpuTarget() {
            return this.cpuTarget;
        }

        @Override
        public final java.lang.Number getMaxNodes() {
            return this.maxNodes;
        }

        @Override
        public final java.lang.Number getMinNodes() {
            return this.minNodes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("cpuTarget", om.valueToTree(this.getCpuTarget()));
            data.set("maxNodes", om.valueToTree(this.getMaxNodes()));
            data.set("minNodes", om.valueToTree(this.getMinNodes()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.BigtableInstanceClusterAutoscalingConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BigtableInstanceClusterAutoscalingConfig.Jsii$Proxy that = (BigtableInstanceClusterAutoscalingConfig.Jsii$Proxy) o;

            if (!cpuTarget.equals(that.cpuTarget)) return false;
            if (!maxNodes.equals(that.maxNodes)) return false;
            return this.minNodes.equals(that.minNodes);
        }

        @Override
        public final int hashCode() {
            int result = this.cpuTarget.hashCode();
            result = 31 * result + (this.maxNodes.hashCode());
            result = 31 * result + (this.minNodes.hashCode());
            return result;
        }
    }
}

==> cdktf-provider-google-2.0.46-sources.jar: com/hashicorp/cdktf/providers/google/BigtableInstanceClusterAutoscalingConfig.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-03T00:49:20.907Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.BigtableInstanceClusterAutoscalingConfig")
@software.amazon.jsii.Jsii.Proxy(BigtableInstanceClusterAutoscalingConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface BigtableInstanceClusterAutoscalingConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * The target CPU utilization for autoscaling. Value must be between 10 and 80.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#cpu_target BigtableInstance#cpu_target}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getCpuTarget();

    /**
     * The maximum number of nodes for autoscaling.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#max_nodes BigtableInstance#max_nodes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getMaxNodes();

    /**
     * The minimum number of nodes for autoscaling.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#min_nodes BigtableInstance#min_nodes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getMinNodes();

    /**
     * The target storage utilization for autoscaling, in GB, for each node in a cluster.
     * <p>
     * This number is limited between 2560 (2.5TiB) and 5120 (5TiB) for a SSD cluster and between 8192 (8TiB) and 16384 (16 TiB) for an HDD cluster. If not set, whatever is already set for the cluster will not change, or if the cluster is just being created, it will use the default value of 2560 for SSD clusters and 8192 for HDD clusters.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#storage_target BigtableInstance#storage_target}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getStorageTarget() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BigtableInstanceClusterAutoscalingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BigtableInstanceClusterAutoscalingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<BigtableInstanceClusterAutoscalingConfig> {
        java.lang.Number cpuTarget;
        java.lang.Number maxNodes;
        java.lang.Number minNodes;
        java.lang.Number storageTarget;

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getCpuTarget}
         * @param cpuTarget The target CPU utilization for autoscaling. Value must be between 10 and 80. This parameter is required.
         *                  Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#cpu_target BigtableInstance#cpu_target}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cpuTarget(java.lang.Number cpuTarget) {
            this.cpuTarget = cpuTarget;
            return this;
        }

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getMaxNodes}
         * @param maxNodes The maximum number of nodes for autoscaling. This parameter is required.
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#max_nodes BigtableInstance#max_nodes}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder maxNodes(java.lang.Number maxNodes) {
            this.maxNodes = maxNodes;
            return this;
        }

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getMinNodes}
         * @param minNodes The minimum number of nodes for autoscaling. This parameter is required.
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#min_nodes BigtableInstance#min_nodes}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder minNodes(java.lang.Number minNodes) {
            this.minNodes = minNodes;
            return this;
        }

        /**
         * Sets the value of {@link BigtableInstanceClusterAutoscalingConfig#getStorageTarget}
         * @param storageTarget The target storage utilization for autoscaling, in GB, for each node in a cluster.
         *                      This number is limited between 2560 (2.5TiB) and 5120 (5TiB) for a SSD cluster and between 8192 (8TiB) and 16384 (16 TiB) for an HDD cluster. If not set, whatever is already set for the cluster will not change, or if the cluster is just being created, it will use the default value of 2560 for SSD clusters and 8192 for HDD clusters.
         *                      <p>
         *                      Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/bigtable_instance#storage_target BigtableInstance#storage_target}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder storageTarget(java.lang.Number storageTarget) {
            this.storageTarget = storageTarget;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BigtableInstanceClusterAutoscalingConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public BigtableInstanceClusterAutoscalingConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BigtableInstanceClusterAutoscalingConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BigtableInstanceClusterAutoscalingConfig {
        private final java.lang.Number cpuTarget;
        private final java.lang.Number maxNodes;
        private final java.lang.Number minNodes;
        private final java.lang.Number storageTarget;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.cpuTarget = software.amazon.jsii.Kernel.get(this, "cpuTarget", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.maxNodes = software.amazon.jsii.Kernel.get(this, "maxNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.minNodes = software.amazon.jsii.Kernel.get(this, "minNodes", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.storageTarget = software.amazon.jsii.Kernel.get(this, "storageTarget", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.cpuTarget = java.util.Objects.requireNonNull(builder.cpuTarget, "cpuTarget is required");
            this.maxNodes = java.util.Objects.requireNonNull(builder.maxNodes, "maxNodes is required");
            this.minNodes = java.util.Objects.requireNonNull(builder.minNodes, "minNodes is required");
            this.storageTarget = builder.storageTarget;
        }

        @Override
        public final java.lang.Number getCpuTarget() {
            return this.cpuTarget;
        }

        @Override
        public final java.lang.Number getMaxNodes() {
            return this.maxNodes;
        }

        @Override
        public final java.lang.Number getMinNodes() {
            return this.minNodes;
        }

        @Override
        public final java.lang.Number getStorageTarget() {
            return this.storageTarget;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("cpuTarget", om.valueToTree(this.getCpuTarget()));
            data.set("maxNodes", om.valueToTree(this.getMaxNodes()));
            data.set("minNodes", om.valueToTree(this.getMinNodes()));
            if (this.getStorageTarget() != null) {
                data.set("storageTarget", om.valueToTree(this.getStorageTarget()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.BigtableInstanceClusterAutoscalingConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BigtableInstanceClusterAutoscalingConfig.Jsii$Proxy that = (BigtableInstanceClusterAutoscalingConfig.Jsii$Proxy) o;

            if (!cpuTarget.equals(that.cpuTarget)) return false;
            if (!maxNodes.equals(that.maxNodes)) return false;
            if (!minNodes.equals(that.minNodes)) return false;
            return this.storageTarget != null ? this.storageTarget.equals(that.storageTarget) : that.storageTarget == null;
        }

        @Override
        public final int hashCode() {
            int result = this.cpuTarget.hashCode();
            result = 31 * result + (this.maxNodes.hashCode());
            result = 31 * result + (this.minNodes.hashCode());
            result = 31 * result + (this.storageTarget != null ? this.storageTarget.hashCode() : 0);
            return result;
        }
    }
}
